﻿using UnityEngine;

public class MotionSampleDisplay : MonoBehaviour
{
    [SerializeField]
    GameObject        left,
                      right;

    public Sprite     sprite;
    public float      timeout;
    public MotionNote caller;

    private float     elapsedTime;
    private float     acceleration;

    private float     distance = 1.5f;
    private Vector3   localScaleLR = new Vector3(0.5f, 0.5f, 0);

    private Vector3 InitialTranslateL
    {
        get
        {
            var tmp = InitialTranslateR;
            tmp.x = -tmp.x;
            return tmp;
        }
    }
    private Vector3 InitialTranslateR
    {
        get
        {
            return new Vector3(distance, -0.8f, 0);
        }
    }

    // Use this for initialization
    void Start()
    {
        elapsedTime = 0f;
        acceleration = 2 * distance / Mathf.Pow(timeout, 2);
        
        SetObject(left, true);
        SetObject(right, false);
    }

    void SetObject(GameObject obj, bool isLeft)
    {
        obj.GetComponent<SpriteRenderer>().sprite = sprite;
        obj.transform.Translate(isLeft ? InitialTranslateL : InitialTranslateR);
        obj.transform.localScale = localScaleLR;
    }

    // Update is called once per frame
    void Update()
    {
        var delta = Time.deltaTime * 1000f;
        elapsedTime += delta;
        if (elapsedTime > timeout)
        {
            Destroy(gameObject);
            return;
        }

        var velocity = acceleration * elapsedTime;
        var movement = velocity * delta;
        left .transform.Translate(new Vector3(movement, 0, 0));
        right.transform.Translate(new Vector3(-movement, 0, 0));
    }
}